Package 'jpaRmd'

Title: Rmarkdown templates for Japanese journals in psychology
Description: The package provides the Rmarkdown template for Japanese journals in psychology including the Japanese Journal of Psychology and so on. The package also provides function making a list of references.
Authors: Yoshihiko Kunisato [aut, cre, cph],Koji Kosugi [aut]
Maintainer: Yoshihiko Kunisato <[email protected]>
License: MIT + file LICENSE
Version: 0.5.5
Built: 2026-05-31 08:31:13 UTC
Source: https://github.com/ykunisato/jpaRmd

Help Index


bib_Checker function

Description

bib_Checker function

Usage

bib_Checker(Rmd_file = "RmdFileName", Bib_file = "BibFileName")

Arguments

Rmd_file

file name of R Markdown file

Bib_file

file name of Bib file

Examples

# bib_Checker(Rmd_file = "RmdFileName",Bib_file = "BibFileName")

bib_to_DF

Description

bib_to_DF

Usage

bib_to_DF(
  Rmd_file,
  Bib_file,
  list_ampersand = T,
  cite_ampersand = F,
  underline = F
)

Arguments

Rmd_file

file name of R Markdown file

Bib_file

file name of Bib file

list_ampersand

combinle the last author with & or not in Bibliography

cite_ampersand

combinle the last author with & or not in in-line citation

underline

Whether to underline emphasis or not. if FALSE, emph as Italic.

Value

Prepare for citation database

Examples

# bib_to_DF(Rmd_file = "RmdFileName",Bib_file = "BibFileName")

citationMaker function

Description

citationMaker function

Usage

citationMaker(df, ampersand = T)

Arguments

df

Bib data frame

ampersand

it TRUE, combine last author with ampersand else "and"


inLine Citation

Description

inLine Citation

Usage

inLineCitation(st, bib.df)

Arguments

st

A line of text

bib.df

Bib.df object created by bib_to_DF function

Value

replace statement

Examples

# bib_to_DF(Rmd_file = "RmdFileName",Bib_file = "BibFileName")

in-Line Cittion(in English)

Description

in-Line Cittion(in English)

Usage

inLineCite_ENG(df, ampersand)

Arguments

df

Bib.df File from jpa_cite

ampersand

it TRUE, combine last author with ampersand else "and"


in-Line Cittion(in Japanese)

Description

in-Line Cittion(in Japanese)

Usage

inLineCite_JPN(df)

Arguments

df

Bib.df File from jpa_cite


in-Line Cittion(Japanese Transration book)

Description

in-Line Cittion(Japanese Transration book)

Usage

inLineCite_TR(df, ampersand)

Arguments

df

Bib.df File from jpa_cite


Add citation with JPA format

Description

Add citation with JPA format

Usage

jpa_cite(Rmd_file, Bib_file, use.et.al.first = TRUE)

Arguments

Rmd_file

file name of R Markdown file

Bib_file

file name of Bib file

Value

Make reference list and add it to R Markdown file

Examples

# jpa_cite(Rmd_file = "RmdFileName",Bib_file = "BibFileName")

Add citation with JPR format

Description

Add citation with JPR format

Usage

jpr_cite(Rmd_file, Bib_file)

Arguments

Rmd_file

file name of R Markdown file

Bib_file

file name of Bib file

Value

Make reference list and add it to R Markdown file

Examples

# jpr_cite(Rmd_file = "RmdFileName",Bib_file = "BibFileName")

Make crrection table

Description

Make crrection table

Usage

make_correction_table(old_manuscript, new_manuscript)

Arguments

old_manuscript

vector of old content of manuscript

new_manuscript

vector of new content of manuscript


Name spliter function

Description

Name spliter function

Usage

name_spliter(df)

Arguments

df

elements of data.frame contains NAME


Add new content of manuscript to crrection table

Description

Add new content of manuscript to crrection table

Usage

new_m(new_text)

Arguments

new_text

new content of manuscript


Add old content of manuscript to crrection table

Description

Add old content of manuscript to crrection table

Usage

old_m(old_text)

Arguments

old_text

old content of manuscript


pBibMaker function

Description

pBibMaker function

Usage

pBibMaker(df, underline)

Arguments

df

Bib data frame

underline

check flag for underline


prefixMaker function

Description

prefixMaker function

Usage

prefixMaker(df)

Arguments

df

Bib data frame


Print bib info function(English article)

Description

Print bib info function(English article)

Usage

print_English_article(df, underline = F)

Arguments

df

Strings of Bib info

underline

check flag for underline


Print bib info function(Jaopanese article)

Description

Print bib info function(Jaopanese article)

Usage

print_Japanese_article(df, underline = F)

Arguments

df

Strings of Bib info

underline

check flag for underline


render function for paper of Japanese Journal of Behavioral and Cognitive Therapies

Description

render function for paper of Japanese Journal of Behavioral and Cognitive Therapies

Usage

render_jjbct(Rmd_file, Bib_file, use.et.al.first = T)

Arguments

Rmd_file

file name of R Markdown file

Bib_file

file name of Bib file


render function for paper of Japanese Journal of Psychology

Description

render function for paper of Japanese Journal of Psychology

Usage

render_jjp(Rmd_file, Bib_file, use.et.al.first = T)

Arguments

Rmd_file

file name of R Markdown file

Bib_file

file name of Bib file


render function for paper of Japanese Psychological Review

Description

render function for paper of Japanese Psychological Review

Usage

render_jpr(Rmd_file, Bib_file)

Arguments

Rmd_file

file name of R Markdown file

Bib_file

file name of Bib file


R Markdown template for Reply to reviewers

Description

R Markdown template for Reply to reviewers

Usage

reply()

Set Research Compendium for JABCT

Description

Set Research Compendium for JABCT

Usage

set_rc_jabct(file_name = "paper")

Arguments

file_name

file name and directory name of RMarkdown

Value

Make directories for Research Compendium of JABCT and R Markdown file

Examples

# set_rc_jabct("rmarkdown_for_reproducibility")

Set Research Compendium for JPA

Description

Set Research Compendium for JPA

Usage

set_rc_jpa(file_name = "paper")

Arguments

file_name

file name and directory name of RMarkdown

Value

Make directories for Research Compendium of JPA and R Markdown file

Examples

# set_rc_jpa("rmarkdown_for_reproducibility")

Extractor function

Description

Extractor function

Usage

value_extractor(string)

Arguments

string

string which contains { or \"