| Title: | Rmarkdown templates for Japanese journals in psychology |
|---|---|
| Description: | The package provides the Rmarkdown template for Japanese journals in psychology including the Japanese Journal of Psychology and so on. The package also provides function making a list of references. |
| Authors: | Yoshihiko Kunisato [aut, cre, cph],Koji Kosugi [aut] |
| Maintainer: | Yoshihiko Kunisato <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.5.5 |
| Built: | 2026-05-31 08:31:13 UTC |
| Source: | https://github.com/ykunisato/jpaRmd |
bib_Checker function
bib_Checker(Rmd_file = "RmdFileName", Bib_file = "BibFileName")bib_Checker(Rmd_file = "RmdFileName", Bib_file = "BibFileName")
Rmd_file |
file name of R Markdown file |
Bib_file |
file name of Bib file |
# bib_Checker(Rmd_file = "RmdFileName",Bib_file = "BibFileName")# bib_Checker(Rmd_file = "RmdFileName",Bib_file = "BibFileName")
bib_to_DF
bib_to_DF( Rmd_file, Bib_file, list_ampersand = T, cite_ampersand = F, underline = F )bib_to_DF( Rmd_file, Bib_file, list_ampersand = T, cite_ampersand = F, underline = F )
Rmd_file |
file name of R Markdown file |
Bib_file |
file name of Bib file |
list_ampersand |
combinle the last author with & or not in Bibliography |
cite_ampersand |
combinle the last author with & or not in in-line citation |
underline |
Whether to underline emphasis or not. if FALSE, emph as Italic. |
Prepare for citation database
# bib_to_DF(Rmd_file = "RmdFileName",Bib_file = "BibFileName")# bib_to_DF(Rmd_file = "RmdFileName",Bib_file = "BibFileName")
citationMaker function
citationMaker(df, ampersand = T)citationMaker(df, ampersand = T)
df |
Bib data frame |
ampersand |
it TRUE, combine last author with ampersand else "and" |
inLine Citation
inLineCitation(st, bib.df)inLineCitation(st, bib.df)
st |
A line of text |
bib.df |
Bib.df object created by bib_to_DF function |
replace statement
# bib_to_DF(Rmd_file = "RmdFileName",Bib_file = "BibFileName")# bib_to_DF(Rmd_file = "RmdFileName",Bib_file = "BibFileName")
in-Line Cittion(in English)
inLineCite_ENG(df, ampersand)inLineCite_ENG(df, ampersand)
df |
Bib.df File from jpa_cite |
ampersand |
it TRUE, combine last author with ampersand else "and" |
in-Line Cittion(in Japanese)
inLineCite_JPN(df)inLineCite_JPN(df)
df |
Bib.df File from jpa_cite |
in-Line Cittion(Japanese Transration book)
inLineCite_TR(df, ampersand)inLineCite_TR(df, ampersand)
df |
Bib.df File from jpa_cite |
Add citation with JPA format
jpa_cite(Rmd_file, Bib_file, use.et.al.first = TRUE)jpa_cite(Rmd_file, Bib_file, use.et.al.first = TRUE)
Rmd_file |
file name of R Markdown file |
Bib_file |
file name of Bib file |
Make reference list and add it to R Markdown file
# jpa_cite(Rmd_file = "RmdFileName",Bib_file = "BibFileName")# jpa_cite(Rmd_file = "RmdFileName",Bib_file = "BibFileName")
Add citation with JPR format
jpr_cite(Rmd_file, Bib_file)jpr_cite(Rmd_file, Bib_file)
Rmd_file |
file name of R Markdown file |
Bib_file |
file name of Bib file |
Make reference list and add it to R Markdown file
# jpr_cite(Rmd_file = "RmdFileName",Bib_file = "BibFileName")# jpr_cite(Rmd_file = "RmdFileName",Bib_file = "BibFileName")
Make crrection table
make_correction_table(old_manuscript, new_manuscript)make_correction_table(old_manuscript, new_manuscript)
old_manuscript |
vector of old content of manuscript |
new_manuscript |
vector of new content of manuscript |
Name spliter function
name_spliter(df)name_spliter(df)
df |
elements of data.frame contains NAME |
Add new content of manuscript to crrection table
new_m(new_text)new_m(new_text)
new_text |
new content of manuscript |
Add old content of manuscript to crrection table
old_m(old_text)old_m(old_text)
old_text |
old content of manuscript |
pBibMaker function
pBibMaker(df, underline)pBibMaker(df, underline)
df |
Bib data frame |
underline |
check flag for underline |
prefixMaker function
prefixMaker(df)prefixMaker(df)
df |
Bib data frame |
Print name function(English)
print_EName(st, ampersand = T, switchFLG = FALSE)print_EName(st, ampersand = T, switchFLG = FALSE)
st |
Strings of name |
ampersand |
it TRUE, combine last author with ampersand else "and" |
switchFLG |
switch the order of first name and last name |
Print bib info function(English article)
print_English_article(df, underline = F)print_English_article(df, underline = F)
df |
Strings of Bib info |
underline |
check flag for underline |
Print bib info function(English book)
print_English_book(df, underline = F)print_English_book(df, underline = F)
df |
Strings of Bib info |
underline |
check flag for underline |
Print bib info function(in English collection)
print_English_incollection(df, underline = F)print_English_incollection(df, underline = F)
df |
Strings of Bib info |
underline |
check flag for underline |
Print bib info function(in English Proceedings)
print_English_inproceedings(df)print_English_inproceedings(df)
df |
Strings of Bib info |
Print bib info function(Original Style references)
print_exceptional_bib(df)print_exceptional_bib(df)
df |
Strings of Bib info |
Print bib info function(Jaopanese article)
print_Japanese_article(df, underline = F)print_Japanese_article(df, underline = F)
df |
Strings of Bib info |
underline |
check flag for underline |
Print bib info function(Japanese book)
print_Japanese_book(df)print_Japanese_book(df)
df |
Strings of Bib info |
Print bib info function(in Japanese collection)
print_Japanese_incollection(df)print_Japanese_incollection(df)
df |
Strings of Bib info |
Print bib info function(in Japanese Proceedings)
print_Japanese_inproceedings(df)print_Japanese_inproceedings(df)
df |
Strings of Bib info |
Print name function(Jpanese)
print_JName(st)print_JName(st)
st |
Strings of Japanese name |
render function for paper of Japanese Journal of Behavioral and Cognitive Therapies
render_jjbct(Rmd_file, Bib_file, use.et.al.first = T)render_jjbct(Rmd_file, Bib_file, use.et.al.first = T)
Rmd_file |
file name of R Markdown file |
Bib_file |
file name of Bib file |
render function for paper of Japanese Journal of Psychology
render_jjp(Rmd_file, Bib_file, use.et.al.first = T)render_jjp(Rmd_file, Bib_file, use.et.al.first = T)
Rmd_file |
file name of R Markdown file |
Bib_file |
file name of Bib file |
render function for paper of Japanese Psychological Review
render_jpr(Rmd_file, Bib_file)render_jpr(Rmd_file, Bib_file)
Rmd_file |
file name of R Markdown file |
Bib_file |
file name of Bib file |
R Markdown template for Reply to reviewers
reply()reply()
Set Research Compendium for JABCT
set_rc_jabct(file_name = "paper")set_rc_jabct(file_name = "paper")
file_name |
file name and directory name of RMarkdown |
Make directories for Research Compendium of JABCT and R Markdown file
# set_rc_jabct("rmarkdown_for_reproducibility")# set_rc_jabct("rmarkdown_for_reproducibility")
Set Research Compendium for JPA
set_rc_jpa(file_name = "paper")set_rc_jpa(file_name = "paper")
file_name |
file name and directory name of RMarkdown |
Make directories for Research Compendium of JPA and R Markdown file
# set_rc_jpa("rmarkdown_for_reproducibility")# set_rc_jpa("rmarkdown_for_reproducibility")
Extractor function
value_extractor(string)value_extractor(string)
string |
string which contains { or \" |